@@ -7,12 +7,16 @@ from .storage import Storage
 class ContextDict:
     storage: Storage
 
+    def __getitem__(self, item: str):
+        return self.storage.data[item]
+
     def __setitem__(self, key: str, value):
         self.storage.data[key] = value
         self.storage.save()
 
-    def __getitem__(self, item: str):
-        return self.storage.data[item]
+    def __delitem__(self, key: str):
+        del self.storage.data[key]
+        self.storage.save()
 
     def __contains__(self, key: str):
         return key in self.storage.data
