@@ -633,6 +633,10 @@ class ChatMemberBanned(ChatMember):
     status: str = 'kicked'
 
 
+ChatMemberT = ChatMemberAdministrator | ChatMemberOwner | ChatMemberRestricted \
+              | ChatMemberBanned | ChatMemberMember | ChatMemberLeft
+
+
 @dataclass
 class ChatMemberUpdated(TgObject):
     """ https://core.telegram.org/bots/api#chatmemberupdated """
